@@ -21,8 +21,10 @@
 
 match_result algorithm_path::match(graph& g, graph& h,gsl_matrix* gm_P_i, gsl_matrix* _gm_ldh, double dalpha_ldh)
 {
-    bool bblast_match=(get_param_i("blast_match")==1);
-    bool bblast_match_end=(get_param_i("blast_match_proj")==1);
+    bool bblast_match=false;
+	  bblast_match=(get_param_i("blast_match")==1);
+    bool bblast_match_end=false;
+    bblast_match_end=(get_param_i("blast_match_proj")==1);
     bool bbest_path_proj=(get_param_i("best_path_proj_sol")==1);
     bool bbest_path_blast_proj=(get_param_i("best_path_blast_proj_sol")==1);
     bool bbest_path_greedy=(get_param_i("best_path_greedy_sol")==1);
@@ -45,6 +47,7 @@ match_result algorithm_path::match(graph& g, graph& h,gsl_matrix* gm_P_i, gsl_ma
     if (pdebug.ivalue) gsl_matrix_printout(gm_Ag_d, "Ag", pdebug.strvalue);
     if (pdebug.ivalue) gsl_matrix_printout(gm_Ah_d, "Ah", pdebug.strvalue);
     //laplacian construction
+    N=g.getN();
     gsl_matrix* gm_Lg_d=gsl_matrix_alloc(N, N);
     gsl_matrix* gm_Lh_d=gsl_matrix_alloc(N, N);
     gsl_matrix_memcpy(gm_Lg_d, gm_Ag_d);
